@@ -1,9 +1,8 @@
 #!/usr/bin/env python3
 
-from .providers import bitcoin, bytom, config
 
 # Shuttle Information's
-__version__ = "0.1.4"
+__version__ = "0.2.0"
 __license__ = "AGPL-3.0"
 __author__ = "Meheret Tesfaye"
 __email__ = "meherett@zoho.com"
@@ -13,8 +12,5 @@ __all__ = [
     "__version__",
     "__license__",
     "__author__",
-    "__email__",
-    "bitcoin",
-    "bytom",
-    "config"
+    "__email__"
 ]
